@@ -1,6 +1,8 @@
+// Copyright (C) 2016 and later: Unicode, Inc. and others.
+// License & terms of use: http://www.unicode.org/copyright.html
 /*
 ********************************************************************************
-*   Copyright (C) 1997-2012, International Business Machines
+*   Copyright (C) 1997-2014, International Business Machines
 *   Corporation and others.  All Rights Reserved.
 ********************************************************************************
 *
@@ -16,16 +18,18 @@
 #define FMTABLE_H
 
 #include "unicode/utypes.h"
-#include "unicode/unistr.h"
-#include "unicode/stringpiece.h"
 
 /**
- * \file 
- * \brief C++ API: Formattable is a thin wrapper for primitive numeric types.
+ * \file
+ * \brief C++ API: Formattable is a thin wrapper for primitive types used for formatting and parsing
  */
 
 #if !UCONFIG_NO_FORMATTING
 
+#include "unicode/unistr.h"
+#include "unicode/stringpiece.h"
+#include "unicode/uformattable.h"
+
 U_NAMESPACE_BEGIN
 
 class CharString;
@@ -58,6 +62,8 @@ class DigitList;
  * within a Formattable.
  *
  * <p>The Formattable class is not suitable for subclassing.
+ *
+ * <p>See UFormattable for a C wrapper.
  */
 class U_I18N_API Formattable : public UObject {
 public:
@@ -82,7 +88,7 @@ public:
      * Creates a Formattable object with a UDate instance.
      * @param d the UDate instance.
      * @param flag the flag to indicate this is a date. Always set it to kIsDate
-     * @stable ICU 2.0  
+     * @stable ICU 2.0
      */
     Formattable(UDate d, ISDATE flag);
 
@@ -121,7 +127,7 @@ public:
      * Creates a Formattable object of an appropriate numeric type from a
      * a decimal number in string form.  The Formattable will retain the
      * full precision of the input in decimal format, even when it exceeds
-     * what can be represented by a double of int64_t.
+     * what can be represented by a double or int64_t.
      *
      * @param number  the unformatted (not localized) string representation
      *                     of the Decimal number.
@@ -130,7 +136,7 @@ public:
      *                decimal number.
      * @stable ICU 4.4
      */
-    Formattable(const StringPiece &number, UErrorCode &status);
+    Formattable(StringPiece number, UErrorCode &status);
 
     /**
      * Creates a Formattable object with a UnicodeString object to copy from.
@@ -181,8 +187,8 @@ public:
      * @stable ICU 2.0
      */
     UBool          operator==(const Formattable &other) const;
-    
-    /** 
+
+    /**
      * Equality operator.
      * @param other    the object to be compared with.
      * @return        TRUE if other are unequal to this, FALSE otherwise.
@@ -191,7 +197,7 @@ public:
     UBool          operator!=(const Formattable& other) const
       { return !operator==(other); }
 
-    /** 
+    /**
      * Destructor.
      * @stable ICU 2.0
      */
@@ -210,7 +216,7 @@ public:
      */
     Formattable *clone() const;
 
-    /** 
+    /**
      * Selector for flavor of data type contained within a
      * Formattable object.  Formattable is a union of several
      * different types, and at any time contains exactly one type.
@@ -273,21 +279,21 @@ public:
      * @stable ICU 2.0
      */
     Type            getType(void) const;
-    
+
     /**
      * Returns TRUE if the data type of this Formattable object
-     * is kDouble, kLong, kInt64 or kDecimalNumber.
+     * is kDouble, kLong, or kInt64
      * @return TRUE if this is a pure numeric object
      * @stable ICU 3.0
      */
     UBool           isNumeric() const;
-    
+
     /**
      * Gets the double value of this object. If this object is not of type
      * kDouble then the result is undefined.
      * @return    the double value of this object.
      * @stable ICU 2.0
-     */ 
+     */
     double          getDouble(void) const { return fValue.fDouble; }
 
     /**
@@ -301,7 +307,7 @@ public:
      * @param status the error code
      * @return the double value of this object.
      * @stable ICU 3.0
-     */ 
+     */
     double          getDouble(UErrorCode& status) const;
 
     /**
@@ -309,7 +315,7 @@ public:
      * kLong then the result is undefined.
      * @return    the long value of this object.
      * @stable ICU 2.0
-     */ 
+     */
     int32_t         getLong(void) const { return (int32_t)fValue.fInt64; }
 
     /**
@@ -318,7 +324,7 @@ public:
      * as appropriate, is returned and the status is set to
      * U_INVALID_FORMAT_ERROR.  If this object is of type kInt64 and
      * it fits within a long, then no precision is lost.  If it is of
-     * type kDouble or kDecimalNumber, then a conversion is peformed, with
+     * type kDouble, then a conversion is peformed, with
      * truncation of any fractional part.  If the type is kObject and
      * the object is a Measure, then the result of
      * getNumber().getLong(status) is returned.  If this object is
@@ -327,7 +333,7 @@ public:
      * @param status the error code
      * @return    the long value of this object.
      * @stable ICU 3.0
-     */ 
+     */
     int32_t         getLong(UErrorCode& status) const;
 
     /**
@@ -335,7 +341,7 @@ public:
      * kInt64 then the result is undefined.
      * @return    the int64 value of this object.
      * @stable ICU 2.8
-     */ 
+     */
     int64_t         getInt64(void) const { return fValue.fInt64; }
 
     /**
@@ -352,7 +358,7 @@ public:
      * @param status the error code
      * @return    the int64 value of this object.
      * @stable ICU 3.0
-     */ 
+     */
     int64_t         getInt64(UErrorCode& status) const;
 
     /**
@@ -360,7 +366,7 @@ public:
      * kDate then the result is undefined.
      * @return    the Date value of this object.
      * @stable ICU 2.0
-     */ 
+     */
     UDate           getDate() const { return fValue.fDate; }
 
     /**
@@ -370,7 +376,7 @@ public:
      * @param status the error code.
      * @return    the Date value of this object.
      * @stable ICU 3.0
-     */ 
+     */
      UDate          getDate(UErrorCode& status) const;
 
     /**
@@ -379,7 +385,7 @@ public:
      * @param result    Output param to receive the Date value of this object.
      * @return          A reference to 'result'.
      * @stable ICU 2.0
-     */ 
+     */
     UnicodeString&  getString(UnicodeString& result) const
       { result=*fValue.fString; return result; }
 
@@ -388,10 +394,10 @@ public:
      * string, status is set to U_INVALID_FORMAT_ERROR and a bogus
      * string is returned.
      * @param result    Output param to receive the Date value of this object.
-     * @param status    the error code. 
+     * @param status    the error code.
      * @return          A reference to 'result'.
      * @stable ICU 3.0
-     */ 
+     */
     UnicodeString&  getString(UnicodeString& result, UErrorCode& status) const;
 
     /**
@@ -425,7 +431,7 @@ public:
      * Gets a reference to the string value of this object. If the
      * type is not a string, status is set to U_INVALID_FORMAT_ERROR
      * and the result is a bogus string.
-     * @param status    the error code. 
+     * @param status    the error code.
      * @return   a reference to the string value of this object.
      * @stable ICU 3.0
      */
@@ -437,7 +443,7 @@ public:
      * @param count    fill-in with the count of this object.
      * @return         the array value of this object.
      * @stable ICU 2.0
-     */ 
+     */
     const Formattable* getArray(int32_t& count) const
       { count=fValue.fArrayAndCount.fCount; return fValue.fArrayAndCount.fArray; }
 
@@ -446,10 +452,10 @@ public:
      * not an array, status is set to U_INVALID_FORMAT_ERROR, count is
      * set to 0, and the result is NULL.
      * @param count    fill-in with the count of this object.
-     * @param status the error code. 
+     * @param status the error code.
      * @return         the array value of this object.
      * @stable ICU 3.0
-     */ 
+     */
     const Formattable* getArray(int32_t& count, UErrorCode& status) const;
 
     /**
@@ -461,7 +467,7 @@ public:
      * @stable ICU 2.0
      */
     Formattable&    operator[](int32_t index) { return fValue.fArrayAndCount.fArray[index]; }
-       
+
     /**
      * Returns a pointer to the UObject contained within this
      * formattable, or NULL if this object does not contain a UObject.
@@ -476,7 +482,7 @@ public:
      * For values obtained by parsing, the returned decimal number retains
      * the full precision and range of the original input, unconstrained by
      * the limits of a double floating point or a 64 bit int.
-     * 
+     *
      * This function is not thread safe, and therfore is not declared const,
      * even though it is logically const.
      *
@@ -495,7 +501,7 @@ public:
      * kDouble.
      * @param d    the new double value to be set.
      * @stable ICU 2.0
-     */ 
+     */
     void            setDouble(double d);
 
     /**
@@ -503,7 +509,7 @@ public:
      * kLong.
      * @param l    the new long value to be set.
      * @stable ICU 2.0
-     */ 
+     */
     void            setLong(int32_t l);
 
     /**
@@ -511,7 +517,7 @@ public:
      * kInt64.
      * @param ll    the new int64 value to be set.
      * @stable ICU 2.8
-     */ 
+     */
     void            setInt64(int64_t ll);
 
     /**
@@ -519,7 +525,7 @@ public:
      * kDate.
      * @param d    the new Date value to be set.
      * @stable ICU 2.0
-     */ 
+     */
     void            setDate(UDate d);
 
     /**
@@ -527,7 +533,7 @@ public:
      * kString.
      * @param stringToCopy    the new string value to be set.
      * @stable ICU 2.0
-     */ 
+     */
     void            setString(const UnicodeString& stringToCopy);
 
     /**
@@ -536,7 +542,7 @@ public:
      * @param array    the array value.
      * @param count    the number of array elements to be copied.
      * @stable ICU 2.0
-     */ 
+     */
     void            setArray(const Formattable* array, int32_t count);
 
     /**
@@ -544,16 +550,16 @@ public:
      * changes the type to kArray.
      * @param stringToAdopt    the new string value to be adopted.
      * @stable ICU 2.0
-     */ 
+     */
     void            adoptString(UnicodeString* stringToAdopt);
 
     /**
      * Sets and adopts the array value and count of this object and
      * changes the type to kArray.
      * @stable ICU 2.0
-     */ 
+     */
     void            adoptArray(Formattable* array, int32_t count);
-       
+
     /**
      * Sets and adopts the UObject value of this object and changes
      * the type to kObject.  After this call, the caller must not
@@ -565,7 +571,7 @@ public:
 
     /**
      * Sets the the numeric value from a decimal number string, and changes
-     * the type to to a numeric type appropriate for the number.  
+     * the type to to a numeric type appropriate for the number.
      * The syntax of the number is a "numeric string"
      * as defined in the Decimal Arithmetic Specification, available at
      * http://speleotrove.com/decimal
@@ -577,7 +583,7 @@ public:
      *                      incoming string is not a valid decimal number.
      * @stable ICU 4.4
      */
-    void             setDecimalNumber(const StringPiece &numberString,
+    void             setDecimalNumber(StringPiece numberString,
                                       UErrorCode &status);
 
     /**
@@ -594,13 +600,47 @@ public:
      */
     static UClassID U_EXPORT2 getStaticClassID();
 
+    /**
+     * Convert the UFormattable to a Formattable.  Internally, this is a reinterpret_cast.
+     * @param fmt a valid UFormattable
+     * @return the UFormattable as a Formattable object pointer.  This is an alias to the original
+     * UFormattable, and so is only valid while the original argument remains in scope.
+     * @stable ICU 52
+     */
+    static inline Formattable *fromUFormattable(UFormattable *fmt);
+
+    /**
+     * Convert the const UFormattable to a const Formattable.  Internally, this is a reinterpret_cast.
+     * @param fmt a valid UFormattable
+     * @return the UFormattable as a Formattable object pointer.  This is an alias to the original
+     * UFormattable, and so is only valid while the original argument remains in scope.
+     * @stable ICU 52
+     */
+    static inline const Formattable *fromUFormattable(const UFormattable *fmt);
+
+    /**
+     * Convert this object pointer to a UFormattable.
+     * @return this object as a UFormattable pointer.   This is an alias to this object,
+     * and so is only valid while this object remains in scope.
+     * @stable ICU 52
+     */
+    inline UFormattable *toUFormattable();
+
+    /**
+     * Convert this object pointer to a UFormattable.
+     * @return this object as a UFormattable pointer.   This is an alias to this object,
+     * and so is only valid while this object remains in scope.
+     * @stable ICU 52
+     */
+    inline const UFormattable *toUFormattable() const;
+
 #ifndef U_HIDE_DEPRECATED_API
     /**
      * Deprecated variant of getLong(UErrorCode&).
      * @param status the error code
      * @return the long value of this object.
      * @deprecated ICU 3.0 use getLong(UErrorCode&) instead
-     */ 
+     */
     inline int32_t getLong(UErrorCode* status) const;
 #endif  /* U_HIDE_DEPRECATED_API */
 
@@ -627,6 +667,15 @@ public:
      *  @internal
      */
     void adoptDigitList(DigitList *dl);
+
+    /**
+     * Internal function to return the CharString pointer.
+     * @param status error code
+     * @return pointer to the CharString - may become invalid if the object is modified
+     * @internal
+     */
+    CharString *internalGetCharString(UErrorCode &status);
+
 #endif  /* U_HIDE_INTERNAL_API */
 
 private:
@@ -687,8 +736,23 @@ inline UnicodeString& Formattable::getString(void) {
 inline int32_t Formattable::getLong(UErrorCode* status) const {
     return getLong(*status);
 }
-#endif
+#endif  /* U_HIDE_DEPRECATED_API */
 
+inline UFormattable* Formattable::toUFormattable() {
+  return reinterpret_cast<UFormattable*>(this);
+}
+
+inline const UFormattable* Formattable::toUFormattable() const {
+  return reinterpret_cast<const UFormattable*>(this);
+}
+
+inline Formattable* Formattable::fromUFormattable(UFormattable *fmt) {
+  return reinterpret_cast<Formattable *>(fmt);
+}
+
+inline const Formattable* Formattable::fromUFormattable(const UFormattable *fmt) {
+  return reinterpret_cast<const Formattable *>(fmt);
+}
 
 U_NAMESPACE_END
 
