@@ -1,9 +1,10 @@
+// |jit-test| error: StopIteration
 // Returning {throw:} from an onPop handler when yielding works and
-// does not close the generator-iterator.
+// does closes the generator-iterator.
 
 load(libdir + "asserts.js");
 
-var g = newGlobal('new-compartment');
+var g = newGlobal();
 var dbg = new Debugger;
 var gw = dbg.addDebuggee(g);
 dbg.onDebuggerStatement = function handleDebugger(frame) {
@@ -13,8 +14,8 @@ dbg.onDebuggerStatement = function handleDebugger(frame) {
 };
 g.eval("function g() { for (var i = 0; i < 10; i++) { debugger; yield i; } }");
 g.eval("var it = g();");
-var rv = gw.evalInGlobal("it.next();");
+var rv = gw.executeInGlobal("it.next();");
 assertEq(rv.throw, "fit");
 
 dbg.enabled = false;
-assertEq(g.it.next(), 1);
+g.it.next();
