@@ -7,18 +7,18 @@
 #ifndef jit_x86_LOpcodes_x86_h
 #define jit_x86_LOpcodes_x86_h
 
+#include "jit/shared/LOpcodes-shared.h"
+
 #define LIR_CPU_OPCODE_LIST(_)  \
-    _(Unbox)                    \
-    _(UnboxDouble)              \
-    _(Box)                      \
-    _(BoxDouble)                \
-    _(DivI)                     \
-    _(DivPowTwoI)               \
-    _(ModI)                     \
-    _(ModPowTwoI)               \
-    _(PowHalfD)                 \
-    _(UInt32ToDouble)           \
-    _(AsmJSLoadFuncPtr)         \
-    _(AsmJSDivOrMod)
+    _(BoxFloatingPoint)         \
+    _(DivOrModConstantI)        \
+    _(SimdValueInt32x4)         \
+    _(SimdValueFloat32x4)       \
+    _(UDivOrMod)                \
+    _(UDivOrModConstant)        \
+    _(UDivOrModI64)             \
+    _(DivOrModI64)              \
+    _(WasmTruncateToInt64)      \
+    _(Int64ToFloatingPoint)
 
 #endif /* jit_x86_LOpcodes_x86_h */
