@@ -1,21 +1,29 @@
+// |reftest| skip -- obsolete test
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
+//-----------------------------------------------------------------------------
+var BUGNUMBER = 437288;
+var summary = 'for loop turning into a while loop';
+var actual = 'No Hang';
+var expect = 'No Hang';
+
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 358594;
-var summary = 'Do not crash on uneval(this).';
-var actual = '';
-var expect = '';
+test();
+//-----------------------------------------------------------------------------
 
-printBugNumber(BUGNUMBER);
-printStatus (summary);
+function test()
+{
+  enterFunc ('test');
+  printBugNumber(BUGNUMBER);
+  printStatus (summary);
+ 
+  (function() { const x = 1; for (x in null); })();
 
-// don't crash|assert
-f = function () { };
-f.__proto__ = this; 
-Object.defineProperty(this, "m", { set: f, enumerable: true, configurable: true });
-uneval(this);
-reportCompare(expect, actual, summary);
+  reportCompare(expect, actual, summary);
+
+  exitFunc ('test');
+}
