@@ -26,7 +26,6 @@ function test()
     gczeal = (function (){});
   }
 
-  jit(true);
 
   function f()
   {
@@ -35,7 +34,6 @@ function test()
   __proto__.__iterator__ = this.__defineGetter__("", function(){})
     f();
 
-  jit(false);
 
   delete __proto__.__iterator__;
 
