@@ -1,44 +1,372 @@
-/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+/* -*- indent-tabs-mode: nil; js-indent-level: 2 -*-
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-// Explicitly set the default version.
-// See https://bugzilla.mozilla.org/show_bug.cgi?id=522760#c11
-if (typeof version != 'undefined')
-{
-  version(0);
-}
+// NOTE: If you're adding new test harness functionality -- first, should you
+//       at all?  Most stuff is better in specific tests, or in nested shell.js
+//       or browser.js.  Second, supposing you should, please add it to this
+//       IIFE for better modularity/resilience against tests that must do
+//       particularly bizarre things that might break the harness.
+
+(function(global) {
+  /**********************************************************************
+   * CACHED PRIMORDIAL FUNCTIONALITY (before a test might overwrite it) *
+   **********************************************************************/
+
+  var undefined; // sigh
+
+  var Error = global.Error;
+  var Number = global.Number;
+  var String = global.String;
+  var TypeError = global.TypeError;
+
+  var ArrayIsArray = global.Array.isArray;
+  var ObjectCreate = global.Object.create;
+  var ObjectDefineProperty = global.Object.defineProperty;
+  var ReflectApply = global.Reflect.apply;
+  var StringPrototypeEndsWith = global.String.prototype.endsWith;
+
+  var runningInBrowser = typeof global.window !== "undefined";
+  if (runningInBrowser) {
+    // Certain cached functionality only exists (and is only needed) when
+    // running in the browser.  Segregate that caching here.
+
+    var SpecialPowersSetGCZeal =
+      global.SpecialPowers ? global.SpecialPowers.setGCZeal : undefined;
+  }
+
+  var runningInShell = typeof window === "undefined";
+
+  /****************************
+   * GENERAL HELPER FUNCTIONS *
+   ****************************/
+
+  // We could use Array.prototype.pop, but we don't so it's clear exactly what
+  // dependencies this function has on test-modifiable behavior (i.e. none).
+  function ArrayPop(arr) {
+    assertEq(ArrayIsArray(arr), true,
+             "ArrayPop must only be used on actual arrays");
+
+    var len = arr.length;
+    if (len === 0)
+      return undefined;
+
+    var v = arr[len - 1];
+    arr.length--;
+    return v;
+  }
+
+  // We *cannot* use Array.prototype.push for this, because that function sets
+  // the new trailing element, which could invoke a setter (left by a test) on
+  // Array.prototype or Object.prototype.
+  function ArrayPush(arr, val) {
+    assertEq(ArrayIsArray(arr), true,
+             "ArrayPush must only be used on actual arrays");
+
+    var desc = ObjectCreate(null);
+    desc.value = val;
+    desc.enumerable = true;
+    desc.configurable = true;
+    desc.writable = true;
+    ObjectDefineProperty(arr, arr.length, desc);
+  }
+
+  function StringEndsWith(str, needle) {
+    return ReflectApply(StringPrototypeEndsWith, str, [needle]);
+  }
+
+  /****************************
+   * TESTING FUNCTION EXPORTS *
+   ****************************/
+
+  function SameValue(v1, v2) {
+    // We could |return Object.is(v1, v2);|, but that's less portable.
+    if (v1 === 0 && v2 === 0)
+      return 1 / v1 === 1 / v2;
+    if (v1 !== v1 && v2 !== v2)
+      return true;
+    return v1 === v2;
+  }
+
+  var assertEq = global.assertEq;
+  if (typeof assertEq !== "function") {
+    assertEq = function assertEq(actual, expected, message) {
+      if (!SameValue(actual, expected)) {
+        throw new TypeError('Assertion failed: got "' + actual + '", ' +
+                            'expected "' + expected +
+                            (message ? ": " + message : ""));
+      }
+    };
+    global.assertEq = assertEq;
+  }
+
+  function assertEqArray(actual, expected) {
+    var len = actual.length;
+    assertEq(len, expected.length, "mismatching array lengths");
+
+    var i = 0;
+    try {
+      for (; i < len; i++)
+        assertEq(actual[i], expected[i], "mismatch at element " + i);
+    } catch (e) {
+      throw new Error("Exception thrown at index " + i + ": " + e);
+    }
+  }
+  global.assertEqArray = assertEqArray;
+
+  function assertThrows(f) {
+    var ok = false;
+    try {
+      f();
+    } catch (exc) {
+      ok = true;
+    }
+    if (!ok)
+      throw new Error("Assertion failed: " + f + " did not throw as expected");
+  }
+  global.assertThrows = assertThrows;
+
+  function assertThrowsInstanceOf(f, ctor, msg) {
+    var fullmsg;
+    try {
+      f();
+    } catch (exc) {
+      if (exc instanceof ctor)
+        return;
+      fullmsg =
+        "Assertion failed: expected exception " + ctor.name + ", got " + exc;
+    }
+
+    if (fullmsg === undefined) {
+      fullmsg =
+        "Assertion failed: expected exception " + ctor.name + ", " +
+        "no exception thrown";
+    }
+    if (msg !== undefined)
+      fullmsg += " - " + msg;
+
+    throw new Error(fullmsg);
+  }
+  global.assertThrowsInstanceOf = assertThrowsInstanceOf;
+
+  /****************************
+   * UTILITY FUNCTION EXPORTS *
+   ****************************/
+
+  var dump = global.dump;
+  if (typeof global.dump === "function") {
+    // A presumptively-functional |dump| exists, so no need to do anything.
+  } else {
+    // We don't have |dump|.  Try to simulate the desired effect another way.
+    if (runningInBrowser) {
+      // We can't actually print to the console: |global.print| invokes browser
+      // printing functionality here (it's overwritten just below), and
+      // |global.dump| isn't a function that'll dump to the console (presumably
+      // because the preference to enable |dump| wasn't set).  Just make it a
+      // no-op.
+      dump = function() {};
+    } else {
+      // |print| prints to stdout: make |dump| do likewise.
+      dump = global.print;
+    }
+    global.dump = dump;
+  }
+
+  var print;
+  if (runningInBrowser) {
+    // We're executing in a browser.  Using |global.print| would invoke browser
+    // printing functionality: not what tests want!  Instead, use a print
+    // function that syncs up with the test harness and console.
+    print = function print() {
+      var s = "TEST-INFO | ";
+      for (var i = 0; i < arguments.length; i++)
+        s += String(arguments[i]) + " ";
+
+      // Dump the string to the console for developers and the harness.
+      dump(s + "\n");
+
+      // AddPrintOutput doesn't require HTML special characters be escaped.
+      global.AddPrintOutput(s);
+    };
+
+    global.print = print;
+  } else {
+    // We're executing in a shell, and |global.print| is the desired function.
+    print = global.print;
+  }
+
+  var quit = global.quit;
+  if (typeof quit !== "function") {
+    // XXX There's something very strange about quit() in browser runs being a
+    //     function that doesn't quit at all (!).  We should get rid of quit()
+    //     as an integral part of tests in favor of something else.
+    quit = function quit() {};
+    global.quit = quit;
+  }
+
+  var gczeal = global.gczeal;
+  if (typeof gczeal !== "function") {
+    if (typeof SpecialPowersSetGCZeal === "function") {
+      gczeal = function gczeal(z) {
+        SpecialPowersSetGCZeal(z);
+      };
+    } else {
+      gczeal = function() {}; // no-op if not available
+    }
+
+    global.gczeal = gczeal;
+  }
+
+  /******************************************************
+   * TEST METADATA EXPORTS (these are of dubious value) *
+   ******************************************************/
+
+  global.SECTION = "";
+  global.VERSION = "";
+  global.BUGNUMBER = "";
+
+  /*************************************************************************
+   * HARNESS-CENTRIC EXPORTS (we should generally work to eliminate these) *
+   *************************************************************************/
+
+  var PASSED = " PASSED! ";
+  global.PASSED = PASSED;
+
+  var FAILED = " FAILED! ";
+  global.FAILED = FAILED;
+
+  /** Set up test environment. */
+  function startTest() {
+    if (global.BUGNUMBER)
+      global.print("BUGNUMBER: " + global.BUGNUMBER);
+  }
+  global.startTest = startTest;
+
+  var callStack = [];
+
+  /**
+   * Puts funcName at the top of the call stack.  This stack is used to show
+   * a function-reported-from field when reporting failures.
+   */
+  function enterFunc(funcName) {
+    assertEq(typeof funcName, "string",
+             "enterFunc must be given a string funcName");
+
+    if (!StringEndsWith(funcName, "()"))
+      funcName += "()";
+
+    ArrayPush(callStack, funcName);
+  }
+  global.enterFunc = enterFunc;
+
+  /**
+   * Pops the top funcName off the call stack.  funcName, if provided, is used
+   * to check push-pop balance.
+   */
+  function exitFunc(funcName) {
+    assertEq(typeof funcName === "string" || typeof funcName === "undefined",
+             true,
+             "exitFunc must be given no arguments or a string");
+
+    var lastFunc = ArrayPop(callStack);
+    assertEq(typeof lastFunc, "string", "exitFunc called too many times");
+
+    if (funcName) {
+      if (!StringEndsWith(funcName, "()"))
+        funcName += "()";
+
+      if (lastFunc !== funcName) {
+        // XXX Eliminate this dependency on global.reportCompare's identity.
+        global.reportCompare(funcName, lastFunc,
+                             "Test driver failure wrong exit function ");
+      }
+    }
+  }
+  global.exitFunc = exitFunc;
+
+  /** Peeks at the top of the call stack. */
+  function currentFunc() {
+    if (callStack.length == 0)
+      return "top level script";
+
+    return callStack[callStack.length - 1];
+  }
+  global.currentFunc = currentFunc;
+
+  // XXX This function is *only* used in harness functions and really shouldn't
+  //     be exported.
+  var writeFormattedResult =
+    function writeFormattedResult(expect, actual, string, passed) {
+      print((passed ? PASSED : FAILED) + string + ' expected: ' + expect);
+    };
+  global.writeFormattedResult = writeFormattedResult;
+
+  /*****************************************************
+   * RHINO-SPECIFIC EXPORTS (are these used any more?) *
+   *****************************************************/
+
+  function inRhino() {
+    return typeof global.defineClass === "function";
+  }
+  global.inRhino = inRhino;
+
+  function GetContext() {
+    return global.Packages.com.netscape.javascript.Context.getCurrentContext();
+  }
+  global.GetContext = GetContext;
+
+  function OptLevel(i) {
+    i = Number(i);
+    var cx = GetContext();
+    cx.setOptimizationLevel(i);
+  }
+  global.OptLevel = OptLevel;
+})(this);
+
+(function(global) {
+  function getPromiseResult(promise) {
+    var result, error, caught = false;
+    promise.then(r => { result = r; },
+                 e => { caught = true; error = e; });
+    drainJobQueue();
+    if (caught)
+      throw error;
+    return result;
+  }
+
+  function assertEventuallyEq(promise, expected) {
+    assertEq(getPromiseResult(promise), expected);
+  }
+  global.assertEventuallyEq = assertEventuallyEq;
+
+  function assertEventuallyThrows(promise, expectedErrorType) {
+    assertThrowsInstanceOf(() => getPromiseResult(promise), expectedErrorType);
+  };
+  global.assertEventuallyThrows = assertEventuallyThrows;
+
+  function assertEventuallyDeepEq(promise, expected) {
+    assertDeepEq(getPromiseResult(promise), expected);
+  };
+  global.assertEventuallyDeepEq = assertEventuallyDeepEq;
+})(this);
 
 var STATUS = "STATUS: ";
-var VERBOSE = false;
-var SECT_PREFIX = 'Section ';
-var SECT_SUFFIX = ' of test - ';
-var callStack = new Array();
 
 var gDelayTestDriverEnd = false;
 
 var gTestcases = new Array();
 var gTc = gTestcases.length;
-var BUGNUMBER = '';
 var summary = '';
 var description = '';
 var expected = '';
 var actual = '';
 var msg = '';
 
-var SECTION = "";
-var VERSION = "";
-var BUGNUMBER = "";
-
 /*
  * constant strings
  */
 var GLOBAL = this + '';
-var PASSED = " PASSED! ";
-var FAILED = " FAILED! ";
-
-var DEBUG = false;
 
 var DESCRIPTION;
 var EXPECTED;
@@ -63,18 +391,6 @@ function AddTestCase( description, expect, actual ) {
   new TestCase( SECTION, description, expect, actual );
 }
 
-/*
- * Set up test environment.
- *
- */
-function startTest() {
-  // print out bugnumber
-
-  if ( BUGNUMBER ) {
-    print ("BUGNUMBER: " + BUGNUMBER );
-  }
-}
-
 function TestCase(n, d, e, a)
 {
   this.name = n;
@@ -85,7 +401,16 @@ function TestCase(n, d, e, a)
   this.reason = '';
   this.bugnumber = typeof(BUGNUMER) != 'undefined' ? BUGNUMBER : '';
   this.type = (typeof window == 'undefined' ? 'shell' : 'browser');
-  gTestcases[gTc++] = this;
+  ({}).constructor.defineProperty(
+    gTestcases,
+    gTc++,
+    {
+      value: this,
+      enumerable: true,
+      configurable: true,
+      writable: true
+    }
+  );
 }
 
 gFailureExpected = false;
@@ -130,7 +455,7 @@ function expectExitCode(n)
  */
 function inSection(x)
 {
-  return SECT_PREFIX + x + SECT_SUFFIX;
+  return "Section " + x + " of test - ";
 }
 
 /*
@@ -217,36 +542,6 @@ function escapeString (str)
   return result;
 }
 
-/*
- * assertEq(actual, expected [, message])
- *   Throw if the two arguments are not the same.  The sameness of two values
- *   is determined as follows.  If both values are zero, they are the same iff
- *   their signs are the same.  Otherwise, if both values are NaN, they are the
- *   same.  Otherwise, they are the same if they compare equal using ===.
- * see https://bugzilla.mozilla.org/show_bug.cgi?id=480199 and
- *     https://bugzilla.mozilla.org/show_bug.cgi?id=515285
- */
-if (typeof assertEq == 'undefined')
-{
-  var assertEq =
-    function (actual, expected, message)
-    {
-      function SameValue(v1, v2)
-      {
-        if (v1 === 0 && v2 === 0)
-          return 1 / v1 === 1 / v2;
-        if (v1 !== v1 && v2 !== v2)
-          return true;
-        return v1 === v2;
-      }
-      if (!SameValue(actual, expected))
-      {
-        throw new TypeError('Assertion failed: got "' + actual + '", expected "' + expected +
-                            (message ? ": " + message : ""));
-      }
-    };
-}
-
 /*
  * Compare expected result to actual result, if they differ (in value and/or
  * type) report a failure.  If description is provided, include it in the
@@ -258,35 +553,17 @@ function reportCompare (expected, actual, description) {
   var output = "";
 
   if (typeof description == "undefined")
-  {
     description = '';
-  }
-  else if (VERBOSE)
-  {
-    printStatus ("Comparing '" + description + "'");
-  }
 
-  if (expected_t != actual_t)
-  {
+  if (expected_t != actual_t) {
     output += "Type mismatch, expected type " + expected_t +
       ", actual type " + actual_t + " ";
   }
-  else if (VERBOSE)
-  {
-    printStatus ("Expected type '" + expected_t + "' matched actual " +
-                 "type '" + actual_t + "'");
-  }
 
-  if (expected != actual)
-  {
+  if (expected != actual) {
     output += "Expected value '" + toPrinted(expected) +
       "', Actual value '" + toPrinted(actual) + "' ";
   }
-  else if (VERBOSE)
-  {
-    printStatus ("Expected value '" + toPrinted(expected) +
-                 "' matched actual value '" + toPrinted(actual) + "'");
-  }
 
   var testcase = new TestCase("unknown-test-name", description, expected, actual);
   testcase.reason = output;
@@ -318,36 +595,18 @@ function reportMatch (expectedRegExp, actual, description) {
   var output = "";
 
   if (typeof description == "undefined")
-  {
     description = '';
-  }
-  else if (VERBOSE)
-  {
-    printStatus ("Comparing '" + description + "'");
-  }
 
-  if (expected_t != actual_t)
-  {
+  if (expected_t != actual_t) {
     output += "Type mismatch, expected type " + expected_t +
       ", actual type " + actual_t + " ";
   }
-  else if (VERBOSE)
-  {
-    printStatus ("Expected type '" + expected_t + "' matched actual " +
-                 "type '" + actual_t + "'");
-  }
 
   var matches = expectedRegExp.test(actual);
-  if (!matches)
-  {
+  if (!matches) {
     output += "Expected match to '" + toPrinted(expectedRegExp) +
       "', Actual value '" + toPrinted(actual) + "' ";
   }
-  else if (VERBOSE)
-  {
-    printStatus ("Expected match to '" + toPrinted(expectedRegExp) +
-                 "' matched actual value '" + toPrinted(actual) + "'");
-  }
 
   var testcase = new TestCase("unknown-test-name", description, true, matches);
   testcase.reason = output;
@@ -368,175 +627,19 @@ function reportMatch (expectedRegExp, actual, description) {
 }
 
 /*
- * Puts funcName at the top of the call stack.  This stack is used to show
- * a function-reported-from field when reporting failures.
+ * An xorshift pseudo-random number generator see:
+ * https://en.wikipedia.org/wiki/Xorshift#xorshift.2A
+ * This generator will always produce a value, n, where
+ * 0 <= n <= 255
  */
-function enterFunc (funcName)
-{
-  if (!funcName.match(/\(\)$/))
-    funcName += "()";
-
-  callStack.push(funcName);
-}
-
-/*
- * Pops the top funcName off the call stack.  funcName is optional, and can be
- * used to check push-pop balance.
- */
-function exitFunc (funcName)
-{
-  var lastFunc = callStack.pop();
-
-  if (funcName)
-  {
-    if (!funcName.match(/\(\)$/))
-      funcName += "()";
-
-    if (lastFunc != funcName)
-      reportCompare(funcName, lastFunc, "Test driver failure wrong exit function ");
-  }
-}
-
-/*
- * Peeks at the top of the call stack.
- */
-function currentFunc()
-{
-  return callStack[callStack.length - 1];
-}
-
-/*
-  Calculate the "order" of a set of data points {X: [], Y: []}
-  by computing successive "derivatives" of the data until
-  the data is exhausted or the derivative is linear.
-*/
-function BigO(data)
-{
-  var order = 0;
-  var origLength = data.X.length;
-
-  while (data.X.length > 2)
-  {
-    var lr = new LinearRegression(data);
-    if (lr.b > 1e-6)
-    {
-      // only increase the order if the slope
-      // is "great" enough
-      order++;
+function *XorShiftGenerator(seed, size) {
+    let x = seed;
+    for (let i = 0; i < size; i++) {
+        x ^= x >> 12;
+        x ^= x << 25;
+        x ^= x >> 27;
+        yield x % 256;
     }
-
-    if (lr.r > 0.98 || lr.Syx < 1 || lr.b < 1e-6)
-    {
-      // terminate if close to a line lr.r
-      // small error lr.Syx
-      // small slope lr.b
-      break;
-    }
-    data = dataDeriv(data);
-  }
-
-  if (2 == origLength - order)
-  {
-    order = Number.POSITIVE_INFINITY;
-  }
-  return order;
-
-  function LinearRegression(data)
-  {
-    /*
-      y = a + bx
-      for data points (Xi, Yi); 0 <= i < n
-
-      b = (n*SUM(XiYi) - SUM(Xi)*SUM(Yi))/(n*SUM(Xi*Xi) - SUM(Xi)*SUM(Xi))
-      a = (SUM(Yi) - b*SUM(Xi))/n
-    */
-    var i;
-
-    if (data.X.length != data.Y.length)
-    {
-      throw 'LinearRegression: data point length mismatch';
-    }
-    if (data.X.length < 3)
-    {
-      throw 'LinearRegression: data point length < 2';
-    }
-    var n = data.X.length;
-    var X = data.X;
-    var Y = data.Y;
-
-    this.Xavg = 0;
-    this.Yavg = 0;
-
-    var SUM_X  = 0;
-    var SUM_XY = 0;
-    var SUM_XX = 0;
-    var SUM_Y  = 0;
-    var SUM_YY = 0;
-
-    for (i = 0; i < n; i++)
-    {
-      SUM_X  += X[i];
-      SUM_XY += X[i]*Y[i];
-      SUM_XX += X[i]*X[i];
-      SUM_Y  += Y[i];
-      SUM_YY += Y[i]*Y[i];
-    }
-
-    this.b = (n * SUM_XY - SUM_X * SUM_Y)/(n * SUM_XX - SUM_X * SUM_X);
-    this.a = (SUM_Y - this.b * SUM_X)/n;
-
-    this.Xavg = SUM_X/n;
-    this.Yavg = SUM_Y/n;
-
-    var SUM_Ydiff2 = 0;
-    var SUM_Xdiff2 = 0;
-    var SUM_XdiffYdiff = 0;
-
-    for (i = 0; i < n; i++)
-    {
-      var Ydiff = Y[i] - this.Yavg;
-      var Xdiff = X[i] - this.Xavg;
-
-      SUM_Ydiff2 += Ydiff * Ydiff;
-      SUM_Xdiff2 += Xdiff * Xdiff;
-      SUM_XdiffYdiff += Xdiff * Ydiff;
-    }
-
-    var Syx2 = (SUM_Ydiff2 - Math.pow(SUM_XdiffYdiff/SUM_Xdiff2, 2))/(n - 2);
-    var r2   = Math.pow((n*SUM_XY - SUM_X * SUM_Y), 2) /
-      ((n*SUM_XX - SUM_X*SUM_X)*(n*SUM_YY-SUM_Y*SUM_Y));
-
-    this.Syx = Math.sqrt(Syx2);
-    this.r = Math.sqrt(r2);
-
-  }
-
-  function dataDeriv(data)
-  {
-    if (data.X.length != data.Y.length)
-    {
-      throw 'length mismatch';
-    }
-    var length = data.X.length;
-
-    if (length < 2)
-    {
-      throw 'length ' + length + ' must be >= 2';
-    }
-    var X = data.X;
-    var Y = data.Y;
-
-    var deriv = {X: [], Y: [] };
-
-    for (var i = 0; i < length - 1; i++)
-    {
-      deriv.X[i] = (X[i] + X[i+1])/2;
-      deriv.Y[i] = (Y[i+1] - Y[i])/(X[i+1] - X[i]);
-    }
-    return deriv;
-  }
-
-  return 0;
 }
 
 function compareSource(expect, actual, summary)
@@ -713,19 +816,6 @@ function getTestCaseResult(expected, actual)
   return true;
 }
 
-if (typeof dump == 'undefined')
-{
-  if (typeof window == 'undefined' &&
-      typeof print == 'function')
-  {
-    dump = print;
-  }
-  else
-  {
-    dump = (function () {});
-  }
-}
-
 function test() {
   for ( gTc=0; gTc < gTestcases.length; gTc++ ) {
     // temporary hack to work around some unknown issue in 1.7
@@ -742,15 +832,13 @@ function test() {
       print('test(): empty testcase for gTc = ' + gTc + ' ' + e);
     }
   }
-  stopTest();
   return ( gTestcases );
 }
 
 /*
  * Begin printing functions.  These functions use the shell's
- * print function.  When running tests in the browser, these
- * functions, override these functions with functions that use
- * document.write.
+ * print function.  When running tests in the browser, browser.js
+ * overrides these functions to write to the page.
  */
 
 function writeTestCaseResult( expect, actual, string ) {
@@ -762,11 +850,6 @@ function writeTestCaseResult( expect, actual, string ) {
   }
   return passed;
 }
-function writeFormattedResult( expect, actual, string, passed ) {
-  var s = ( passed ? PASSED : FAILED ) + string + ' expected: ' + expect;
-  print(s);
-  return passed;
-}
 
 function writeHeaderToLog( string ) {
   print( string );
@@ -774,32 +857,6 @@ function writeHeaderToLog( string ) {
 /* end of print functions */
 
 
-/*
- * When running in the shell, run the garbage collector after the
- * test has completed.
- */
-
-function stopTest() {
-  var gc;
-  if ( gc != undefined ) {
-    gc();
-  }
-}
-
-/*
- * Convenience function for displaying failed test cases.  Useful
- * when running tests manually.
- *
- */
-function getFailedCases() {
-  for ( var i = 0; i < gTestcases.length; i++ ) {
-    if ( ! gTestcases[i].passed ) {
-      print( gTestcases[i].description + " = " +gTestcases[i].actual +
-             " expected: " + gTestcases[i].expect );
-    }
-  }
-}
-
 function jsTestDriverEnd()
 {
   // gDelayTestDriverEnd is used to
@@ -830,27 +887,3 @@ function jsTestDriverEnd()
   }
 
 }
-
-function jit(on)
-{
-}
-
-/*
- * Some tests need to know if we are in Rhino as opposed to SpiderMonkey
- */
-function inRhino()
-{
-  return (typeof defineClass == "function");
-}
-
-/* these functions are useful for running tests manually in Rhino */
-
-function GetContext() {
-  return Packages.com.netscape.javascript.Context.getCurrentContext();
-}
-function OptLevel( i ) {
-  i = Number(i);
-  var cx = GetContext();
-  cx.setOptimizationLevel(i);
-}
-/* end of Rhino functions */
