@@ -4,17 +4,13 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch07/7.6/7.6-12.js
- * @description 7.6 - SyntaxError expected: reserved words used as Identifier Names in UTF8: try (try)
+ * @path ch07/7.3/7.3-1.js
+ * @description 7.3 - ES5 recognizes the character <LS> (\u2028) as line terminators when parsing statements
  */
 
 
 function testcase() {
-            try {
-                eval("var \u0074\u0072\u0079 = 123;");  
-                return false;
-            } catch (e) {
-                return e instanceof SyntaxError;  
-            }
+        eval("var test7_3_1\u2028prop = 66;");
+        return (prop === 66) && ((typeof test7_3_1) === "undefined");
     }
 runTestCase(testcase);
