@@ -4,20 +4,20 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch07/7.6/7.6.1/7.6.1-7-7.js
- * @description Allow reserved words as property names by index assignment, accessed via indexing: while, debugger, function
+ * @path ch07/7.6/7.6.1/7.6.1-7-10.js
+ * @description Allow reserved words as property names by index assignment, accessed via indexing: in, try, class
  */
 
 
 function testcase() {
         var tokenCodes = {};
-        tokenCodes['while'] = 0;
-        tokenCodes['debugger'] = 1;
-        tokenCodes['function'] = 2; 
+        tokenCodes['in'] = 0;
+        tokenCodes['try'] = 1;
+        tokenCodes['class'] = 2;
         var arr = [
-            'while',
-            'debugger',
-            'function'
+            'in',
+            'try',
+            'class'
         ];
         for (var i = 0; i < arr.length; i++) {
             if (tokenCodes[arr[i]] !== i) {
