@@ -4,12 +4,18 @@
 /// "Use Terms").   Any redistribution of this code must retain the above
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch10/10.4/10.4.3/10.4.3-1-82gs.js
- * @description Strict - checking 'this' from a global scope (non-strict function declaration called by strict eval)
- * @noStrict
+ * @path ch10/10.4/10.4.3/10.4.3-1-40gs.js
+ * @description Strict - checking 'this' from a global scope (FunctionExpression defined within a FunctionExpression with a strict directive prologue)
+ * @onlyStrict
  */
 
-function f() { return this!==undefined;};
-if (! ((function () {"use strict"; return eval("f();");})()) ){
-    throw "'this' had incorrect value!";
+var f1 = function () {
+    "use strict";
+    var f = function () {
+        return typeof this;
+    }
+    return (f()==="undefined") && ((typeof this)==="undefined");
 }
+if (! f1()) {
+    throw "'this' had incorrect value!";
+}
\ No newline at end of file
