@@ -4,17 +4,14 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * This test is actually testing the [[Delete]] internal method (8.12.8). Since the
- * language provides no way to directly exercise [[Delete]], the tests are placed here.
- *
- * @path ch11/11.4/11.4.1/11.4.1-4.a-9.js
- * @description delete operator returns false when deleting a non-configurable data property (Math.LN2)
+ * @path ch11/11.1/11.1.4/11.1.4-0.js
+ * @description elements elided at the end of an array do not contribute to its length
  */
 
 
 function testcase() {
-  var d = delete Math.LN2;
-  if (d === false) {
+  var a = [,];
+  if (a.length === 1) {
     return true;
   }
  }
