@@ -4,20 +4,21 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch11/11.13/11.13.2/11.13.2-6-15-s.js
- * @description Strict Mode - SyntaxError is thrown if the identifier arguments appear as the LeftHandSideExpression of a Compound Assignment operator(+=)
+ * @path ch11/11.13/11.13.1/11.13.1-4-6-s.js
+ * @description simple assignment throws TypeError if LeftHandSide is a readonly property in strict mode (Function.length)
  * @onlyStrict
  */
 
 
 function testcase() {
-        "use strict";
-        var blah = arguments;
-        try {
-            eval("arguments += 20;");
-            return false;
-        } catch (e) {
-            return e instanceof SyntaxError && blah === arguments;
-        }
-    }
+  'use strict';
+  
+  try {
+    Function.length = 42;
+    return false;
+  }
+  catch (e) {
+    return (e instanceof TypeError);
+  }
+ }
 runTestCase(testcase);
