@@ -2,16 +2,16 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /**
- * Expression in "do-while" IterationStatement is bracketed with braces
+ * Expression in "while" IterationStatement is bracketed with braces
  *
- * @path ch12/12.6/12.6.1/S12.6.1_A6_T2.js
- * @description Checking if execution of "do{} while 0" fails
+ * @path ch12/12.6/12.6.2/S12.6.2_A6_T2.js
+ * @description Checking if execution of "while 0 break" fails
  * @negative
  */
 
 //////////////////////////////////////////////////////////////////////////////
 //CHECK#1
-do break; while 0;
+while 0 break;
 //
 //////////////////////////////////////////////////////////////////////////////
 
