@@ -4,19 +4,20 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch13/13.2/13.2-3-s.js
- * @description StrictMode - Writing or reading from a property named 'arguments' of function objects is allowed under both strict and normal modes.
+ * @path ch13/13.2/13.2-7-s.js
+ * @description StrictMode - enumerating over a function object looking for 'caller' fails outside of the function
  * @onlyStrict
  */
 
 
 function testcase() {
-        "use strict";
-
-        var foo = function () {
-            this.arguments = 12;
-        } 
-        var obj = new foo();
-        return obj.arguments === 12;
+        var foo = new Function("'use strict';");
+        
+        for (var tempIndex in foo) {
+            if (tempIndex === "caller") {
+                return false;
+            }
+        }
+        return true;
     }
 runTestCase(testcase);
